PyLadies Kit

This kit contains the PyLadies Handbook (nicely viewable at http://kit.pyladies.com) as well as other useful materials for organizing your own PyLadies chapter.


To try out:

```bash
$ pip install pyladies
$ pyladies handbook
```